#
# spec file for package openlmi-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Redhat, Inc
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openlmi-tools
Version:        0.10.5
Release:        2.2
%if 0%{?suse_version}
%else
%endif
Summary:        Tooling around openLMI
License:        GPL-2.0
Group:          System/Management
%if 0%{?suse_version} > 1110
# SLE11 has Python site-dir below /usr/lib64
BuildArch:      noarch
%endif

Url:            http://fedorahosted.org/openlmi/
Source0:        https://fedorahosted.org/released/openlmi-tools/%{name}-%{version}.tar.gz
Source1:        http://docs.openlmi.org/en/latest/objects.inv
%if 0%{?suse_version} == 1110
# Python 2.6 vs 2.7 dict creation syntax change, kkaempf@suse.de
# See http://stackoverflow.com/questions/1747817/python-create-a-dictionary-with-list-comprehension
Patch:          python-2.6.patch
%endif

BuildRequires:  ImageMagick
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  openlmi-python-base
BuildRequires:  openwsman-python
BuildRequires:  python-docopt
BuildRequires:  python-pywbem
BuildRequires:  python-sphinx
BuildRequires:  python-sphinx_rtd_theme
%if 0%{?suse_version} < 1120
# SLE11 needs explicit BuildRoot
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Python 2.6 needs argparse
BuildRequires:  python-argparse
%endif
%if 0%{?suse_version}
BuildRequires:  python
BuildRequires:  python-M2Crypto
BuildRequires:  python-pyparsing
%if 0%{?suse_version} > 1110
BuildRequires:  python-ply
BuildRequires:  python-pyOpenSSL
%else
BuildRequires:  python-openssl
%endif
%else
Requires:       m2crypto
Requires:       pyparsing
Requires:       python2
%endif

%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif

# sblim-sfcb or tog-pegasus
# (required to be present during install/uninstall for registration)
Requires:       cim-server
Requires(pre):  cim-server
Requires(preun): cim-server
Requires(post): cim-server

# XXX
# Just because we have wired python's scripts
# Remove in future
BuildRequires:  python-setuptools

%description
%{name} is set of tools to build and work with openLMI providers

%prep
%setup -q
%if 0%{?suse_version} == 1110
%patch -p1
%endif

%build
cp %{S:1} doc/src
PAPER=a4 make

%install
cd cli
python setup.py install --root="%{buildroot}" --prefix=%{_prefix}
install -d %{buildroot}%{_mandir}/man1
install -pm0644 man/lmi.1 %{buildroot}%{_mandir}/man1

%if 0%{?suse_version} > 1010
%fdupes %{buildroot}
%endif

%files
%defattr(-,root,root,-)
%doc README.md COPYING AUTHORS
%{_bindir}/lmi*
%dir %{python_sitelib}/lmi
%dir %{python_sitelib}/openlmi_tools-*-info
%{python_sitelib}/lmi*
%{python_sitelib}/openlmi_tools-*-nspkg.pth
%{python_sitelib}/openlmi_tools-*-info/*
%{_mandir}/man1/lmi.1*

%changelog
* Fri Jul  1 2016 jengelh@inai.de
- Resolve rpmlint warning about spurious +x bits
* Sat Jun 18 2016 kkaempf@suse.com
- fix build: buildrequire python-ply
* Fri Mar 20 2015 kkaempf@suse.com
- Update to 0.10.5
  - Bugfixes
* Fri Dec 12 2014 kkaempf@suse.com
- Update to 0.10.4
  - Bugfixes
* Thu Dec 11 2014 kkaempf@suse.com
- Update to 0.10.3
  - WS-Man support is now optional
  - documentation cleanup
* Wed Oct 29 2014 kkaempf@suse.com
- Update to 0.10.2
  - improve exception wrapping
  - CIMError contains also an origin of the error
  - scripts: added CONNECTION_TIMEOUT property
  - added min_column_sizes param to the TableFormatter
  - documentation overhaul
  - restructured
  - use readthedocs theme
  - fix signal() behavior in non-main thread
  - fix missing indication reply
* Tue Sep  2 2014 kkaempf@suse.com
- Update to 0.10.1
  - LMIWBEM is now used as primary WBEM backend (see [2])
  - python 2.6 compatibility backports
  - introduced WS-MAN support
  - introduced compatibility module for PyWBEM
  - introduced secure connection for indications using SSL
  - better handle job output parameters
  - introduce LMIInstanceName::delete()
  - allow LMIInstanceNames to call CIMMethods
  - allow root and pegasus members to connect via Unix socket
  - raise CIMError when synchronous method call fails
  - fix synchro methods indication listener startup
  - fix compat.CIMIndicationListener indication delivery
  - various fixes
* Tue Jul  1 2014 kkaempf@suse.com
- Update to 0.9.2
  - documentation fixes
  - improved caching
  - improved logging when calling synchro methods
  - no class name verification when creating LMIClass
  - added tests for lmi meta-command
  - backport to python 2.6
  - various fixes
- Add lmi.1 manpage
* Fri Apr 18 2014 kkaempf@suse.com
- Update to 0.9.1
  - Indication subscription is simplified
  - Indication receiving timeout is fixed
  - CIMOM's certificate verification is fixed
  - LMIInstance(Name) can be compared to each other
  - LMIInstance objects can be filtered at client's side
  - connecting via Unix socket is improved
  - _association_ methods can be called within LMIInstanceName objects
  - interactive shell is improved
  - logging
  - lmi meta-command now lives in openlmi-tools repository
  - Python 2.6 backports
  - various fixes
* Sun Feb  9 2014 kkaempf@suse.com
- SLE-12: FATE 316180
* Mon Jan 20 2014 kkaempf@suse.com
- fix SLE11 build, add python-2.6.patch
* Tue Nov  5 2013 kkaempf@suse.com
- Update to version 0.9
  - synchronous calls can properly handle empty JobOutputParameters
  - fixed calls, where CIMInstance(Name) objects were not wrapped
  - .wrapped_object() method can retrieve wrapped CIM object
  - shell abstractions are accepted by the shell methods
  - various fixes
  NOTE: When calling a method, LMIInstance objects are no longer
  autorefreshed. This needs to be done by hand (.refresh()).
* Tue Nov  5 2013 kkaempf@suse.com
- Update to version 0.8
  - method calls, which work with LMI_SoftwareVerificationJob
    can now be called in synchronous way
  - clients can be authenticated by x509 certificates
  - method calls' arguments are now passed via dictionary
  - instances do not auto-refresh after a method call
  - lmi_associators can be used to speed up associations traversal
  - when calling synchronous method, lmishell now properly handles
    SIGTERM and SIGINT
  - shell prompt can be customized now (due to scriptons)
  - LMIShell has a html documentation now; generated using sphinx
  - man page is generated using sphinx
  - bash completion
  - zsh completion
  - various fixes
* Fri Sep 27 2013 kkaempf@suse.com
- fix build for SLE11
* Tue Aug 13 2013 kkaempf@suse.com
- Update to version 0.7
  - all necessary classes are already available when lmishell is run
  - connect() does not ask for username/password, if not provided
  - only non-interactive mode affected
  - synchronous method calls return proper return value and parameters
  - introduced reversed constant values
  - returns string representation of constant value
  - dropped display hook
  - fixed installation to user directory
  - introduced server side certificate check, if ssl used
  - LMI* wrapper objects now have .connection property
  - it references the LMIConnection object returned by connect()
  - introduced --noverify option
  - tells lmishell to skip server-side certificate check
  - fixed class names in LMIClass::instances()
  - introduced lmi_isinstance()
  - similar to python's isinstance()
  - returns, whether LMIInstance/LMIInstanceName is instance of LMIClass
  - works for superclass too
  - introduced custom help() function
  - currently it displays "man lmishell"
  - various small/bug fixes
* Wed Jul 31 2013 kkaempf@suse.com
- Update to version 0.6
  - indications support; subscription and listening
  - lazy class fetching when working with LMIClasses
  - classes caching
  - UDS connection to TOG-Pegasus, when connections as root to localhost
  - configuration file (~/.lmishellrc)
  - dictionary-based filtering for LMIInstance and LMIInstanceName
  - synchronous method calls
  - not 100%% complete, we are waiting for TOG-Pegasus for fixes
  - creation of a new LMIInstanceName
  - access constant values (Values + ValueMap from MOF definition)
  - no sample scripts present
  - history file renamed to ~/.lmishell_history
  - man page generator
  - uses https://fedorahosted.org/openlmi/wiki/shell pages to generate
    the man page content
  - moved the shell into $(PYTHON_SITELIB)/lmi/shell to make the
    shell compatible with other providers, etc.
  - switched from autotools to setuptools
  - new CLI options for basic logging setup
  - bug fixes and code cleanups
* Fri Jul 26 2013 kkaempf@suse.com
- Fix SLE 11 build
  Add older-python.patch
* Fri Apr 12 2013 kkaempf@suse.com
- Initial version 0.5
